@@ -22,7 +22,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "target.h"
 #include "../basic/config.h"
 #include "../data/reference.h"
-#include "culling.h"
 
 using std::vector;
 using std::list;
@@ -67,8 +66,10 @@ void Target::inner_culling(int source_query_len) {
 void Match::inner_culling(int source_query_len)
 {
 	Extension::inner_culling(hsp, source_query_len);
-	if (!hsp.empty())
+	if (!hsp.empty()) {
+		filter_evalue = hsp.front().evalue;
 		filter_score = hsp.front().score;
+	}
 }
 
 void Match::max_hsp_culling() {
@@ -85,12 +86,15 @@ bool append_hits(vector<Target>& targets, vector<Target>::const_iterator begin,
 		append = true;
 
 	int max_score = 0;
-	for (auto i = begin; i < end; ++i)
+	double min_evalue = DBL_MAX;
+	for (auto i = begin; i < end; ++i) {
 		max_score = std::max(max_score, i->filter_score);
+		min_evalue = std::min(min_evalue, i->filter_evalue);
+	}
 
 	if (targets.empty())
 		append = true;
-	else if (config.toppercent == 100.0 && max_score >= targets.back().filter_score)
+	else if (config.toppercent == 100.0 && min_evalue <= targets.back().filter_evalue)
 		append = true;
 	else if (config.toppercent != 100.0 && max_score >= top_cutoff_score(targets.front().filter_score))
 		append = true;
@@ -122,12 +126,14 @@ void Target::apply_filters(int source_query_len, const char *query_title, const
 	const sequence seq = ref_seqs::get()[block_id];
 	const int len = seq.length();
 	filter_score = 0;
+	filter_evalue = DBL_MAX;
 	for (unsigned frame = 0; frame < align_mode.query_contexts; ++frame) {
 		for (list<Hsp>::iterator i = hsp[frame].begin(); i != hsp[frame].end();) {
 			if (filter_hsp(*i, source_query_len, query_title, len, title, query_seq, seq))
 				i = hsp[frame].erase(i);
 			else {
 				filter_score = std::max(filter_score, i->score);
+				filter_evalue = std::min(filter_evalue, i->evalue);
 				++i;
 			}
 		}
@@ -145,7 +151,36 @@ void Match::apply_filters(int source_query_len, const char *query_title, const s
 		else
 			++i;
 	}
+	filter_evalue = hsp.empty() ? DBL_MAX : hsp.front().evalue;
 	filter_score = hsp.empty() ? 0 : hsp.front().score;
 }
 
+void culling(std::vector<Target>& targets, int source_query_len, const char* query_title, const sequence& query_seq, size_t min_keep) {
+	if (config.min_id > 0 || config.query_cover > 0 || config.subject_cover > 0 || config.no_self_hits)
+		for (Target& match : targets)
+			match.apply_filters(source_query_len, query_title, query_seq);
+
+	std::sort(targets.begin(), targets.end(), config.toppercent < 100.0 ? Target::comp_score : Target::comp_evalue);
+	if (targets.empty() || targets.front().filter_evalue == DBL_MAX) {
+		targets.clear();
+		return;
+	}
+
+	std::vector<Target>::iterator i = targets.begin();
+	if (config.toppercent < 100.0) {
+		size_t n = 0;
+		const double cutoff = std::max(top_cutoff_score(score_matrix.bitscore(targets.front().filter_score)), 1.0);
+		while (i < targets.end() && (score_matrix.bitscore(i->filter_score) >= cutoff || n < min_keep)) {
+			++i;
+			++n;
+		}
+	}
+	else {
+		i += std::min(std::max(config.max_alignments, min_keep), targets.size());
+		while (--i > targets.begin() && i->filter_evalue == DBL_MAX);
+		++i;
+	}
+	targets.erase(i, targets.end());
+}
+
 }
\ No newline at end of file
