@@ -83,16 +83,23 @@ Match::Match(size_t target_block_id, std::array<std::list<Hsp>, MAX_CONTEXT> &hs
 		max_hsp_culling();
 }
 
-void add_dp_targets(const WorkTarget &target, int target_idx, const sequence *query_seq, array<array<vector<DpTarget>, 2>, MAX_CONTEXT> &dp_targets, int flags) {
+void add_dp_targets(const WorkTarget& target, int target_idx, const sequence* query_seq, array<array<vector<DpTarget>, 3>, MAX_CONTEXT>& dp_targets, int flags) {
 	const int band = Extension::band((int)query_seq->length()),
 		slen = (int)target.seq.length();
+	const size_t qlen = query_seq[0].length();
 	const Stats::TargetMatrix* matrix = target.matrix.scores.empty() ? nullptr : &target.matrix;
 	for (unsigned frame = 0; frame < align_mode.query_contexts; ++frame) {
 
 		if (config.ext == "full") {
-			int b = target.ungapped_score <= config.cutoff_score_8bit ? 0 : 1;
-			if ((flags & DP::TRACEBACK) && query_seq[0].length() >= 256)
-				b = 1;
+			if (target.ungapped_score[frame] == 0)
+				continue;
+			int b = target.ungapped_score[frame] <= config.cutoff_score_8bit ? 0 : 1;
+			if (flags & DP::TRACEBACK) {
+				if (query_seq[0].length() >= 256)
+					b = 1;
+				if (query_seq[0].length() * target.seq.length() > config.max_swipe_dp)
+					b = 2;
+			}
 			dp_targets[frame][b].emplace_back(target.seq, 0, 0, 0, 0, target_idx, (int)query_seq->length());
 			continue;
 		}
@@ -111,6 +118,8 @@ void add_dp_targets(const WorkTarget &target, int target_idx, const sequence *qu
 				j0 = std::min(j0, hsp.subject_range.begin_);
 				j1 = std::max(j1, hsp.subject_range.end_);
 				bits = std::max(bits, (hsp.score <= config.cutoff_score_8bit && (d1 - d0) < 256) ? 0 : 1);
+				if (flags & DP::TRACEBACK && size_t(d1 - d0) * qlen > config.max_swipe_dp)
+					bits = 2;
 			}
 			else {
 				if (d0 != INT_MAX)
@@ -120,6 +129,8 @@ void add_dp_targets(const WorkTarget &target, int target_idx, const sequence *qu
 				j0 = hsp.subject_range.begin_;
 				j1 = hsp.subject_range.end_;
 				bits = (hsp.score <= config.cutoff_score_8bit && (d1 - d0) < 256) ? 0 : 1;
+				if (flags & DP::TRACEBACK && size_t(d1 - d0) * qlen > config.max_swipe_dp)
+					bits = 2;
 			}
 		}
 
@@ -128,7 +139,7 @@ void add_dp_targets(const WorkTarget &target, int target_idx, const sequence *qu
 }
 
 vector<Target> align(const vector<WorkTarget> &targets, const sequence *query_seq, const Bias_correction *query_cb, int source_query_len, int flags, Statistics &stat) {
-	array<array<vector<DpTarget>, 2>, MAX_CONTEXT> dp_targets;
+	array<array<vector<DpTarget>, 3>, MAX_CONTEXT> dp_targets;
 	vector<Target> r;
 	if (targets.empty())
 		return r;
@@ -138,7 +149,7 @@ vector<Target> align(const vector<WorkTarget> &targets, const sequence *query_se
 		add_dp_targets(targets[i], i, query_seq, dp_targets, flags);
 		if (targets[i].adjusted_matrix())
 			++cbs_targets;
-		r.emplace_back(targets[i].block_id, targets[i].seq, targets[i].ungapped_score, targets[i].matrix);
+		r.emplace_back(targets[i].block_id, targets[i].seq, targets[i].ungapped_score.front(), targets[i].matrix);
 	}
 	stat.inc(Statistics::TARGET_HITS3_CBS, cbs_targets);
 
@@ -152,6 +163,7 @@ vector<Target> align(const vector<WorkTarget> &targets, const sequence *query_se
 			query_seq[frame],
 			dp_targets[frame][0],
 			dp_targets[frame][1],
+			dp_targets[frame][2],
 			nullptr,
 			Frame(frame),
 			Stats::CBS::hauser(config.comp_based_stats) ? &query_cb[frame] : nullptr,
@@ -183,6 +195,7 @@ vector<Target> full_db_align(const sequence *query_seq, const Bias_correction *q
 		query_seq[0],
 		v,
 		v,
+		v,
 		&target_it,
 		Frame(0),
 		Stats::CBS::hauser(config.comp_based_stats) ? &query_cb[0] : nullptr,
@@ -202,7 +215,7 @@ vector<Target> full_db_align(const sequence *query_seq, const Bias_correction *q
 	return r;
 }
 
-void add_dp_targets(const Target &target, int target_idx, const sequence *query_seq, array<array<vector<DpTarget>, 2>, MAX_CONTEXT> &dp_targets) {
+void add_dp_targets(const Target &target, int target_idx, const sequence *query_seq, array<array<vector<DpTarget>, 3>, MAX_CONTEXT> &dp_targets) {
 	const int band = Extension::band((int)query_seq->length()),
 		slen = (int)target.seq.length();
 	const Stats::TargetMatrix* matrix = target.adjusted_matrix() ? &target.matrix : nullptr;
@@ -210,14 +223,17 @@ void add_dp_targets(const Target &target, int target_idx, const sequence *query_
 		const int qlen = (int)query_seq[frame].length();
 		for (const Hsp &hsp : target.hsp[frame]) {
 			const bool byte_row_counter = config.ext == "full" ? qlen < 256 : (hsp.d_end - hsp.d_begin < 256);
-			vector<DpTarget>& v = (hsp.score < 255 && byte_row_counter) ? dp_targets[frame][0] : dp_targets[frame][1];
-			v.emplace_back(target.seq, hsp.d_begin, hsp.d_end, hsp.seed_hit_range.begin_, hsp.seed_hit_range.end_, target_idx, qlen, matrix);
+			int b = (hsp.score < 255 && byte_row_counter) ? 0 : 1;
+			const size_t dp_size = config.ext == "full" ? query_seq[0].length() * target.seq.length() : query_seq[0].length() * size_t(hsp.d_end - hsp.d_begin);
+			if (dp_size > config.max_swipe_dp)
+				b = 2;
+			dp_targets[frame][b].emplace_back(target.seq, hsp.d_begin, hsp.d_end, hsp.seed_hit_range.begin_, hsp.seed_hit_range.end_, target_idx, qlen, matrix);
 		}
 	}
 }
 
 vector<Match> align(vector<Target> &targets, const sequence *query_seq, const Bias_correction *query_cb, int source_query_len, int flags, Statistics &stat, bool first_round_traceback) {
-	array<array<vector<DpTarget>, 2>, MAX_CONTEXT> dp_targets;
+	array<array<vector<DpTarget>, 3>, MAX_CONTEXT> dp_targets;
 	vector<Match> r;
 	if (targets.empty())
 		return r;
@@ -246,6 +262,7 @@ vector<Match> align(vector<Target> &targets, const sequence *query_seq, const Bi
 			query_seq[frame],
 			dp_targets[frame][0],
 			dp_targets[frame][1],
+			dp_targets[frame][2],
 			nullptr,
 			Frame(frame),
 			Stats::CBS::hauser(config.comp_based_stats) ? &query_cb[frame] : nullptr,
