@@ -26,7 +26,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdint.h>
 #include <map>
 
-enum class Sensitivity { FAST = 0, MID_SENSITIVE = 1, SENSITIVE = 2, MORE_SENSITIVE = 3, VERY_SENSITIVE = 4, ULTRA_SENSITIVE = 5 };
+enum class Sensitivity { FAST = 0, DEFAULT = 1, MID_SENSITIVE = 2, SENSITIVE = 3, MORE_SENSITIVE = 4, VERY_SENSITIVE = 5, ULTRA_SENSITIVE = 6 };
 enum class TracebackMode { NONE = 0, SCORE_ONLY = 1, STAT = 2, VECTOR = 3, SCORE_BUFFER = 4 };
 
 struct Config
@@ -38,7 +38,7 @@ struct Config
 	string_vector input_ref_file;
 	unsigned	threads_;
 	string	database;
-	string	query_file;
+	string_vector query_file;
 	unsigned	merge_seq_treshold;
 	unsigned	hit_cap;
 	unsigned shapes;
@@ -246,12 +246,20 @@ struct Config
 	int family_cap;
 	int cbs_matrix_scale;
 	size_t query_count;
-	double cbs_angle;
 	int target_seg;
 	double cbs_err_tolerance;
 	int cbs_it_limit;
 	double query_match_distance_threshold;
 	double length_ratio_threshold;
+	bool hash_join_swap;
+	bool target_indexed;
+	size_t deque_bucket_size;
+	bool mmap_target_index;
+	bool save_target_index;
+	bool mode_fast;
+	double log_evalue_scale;
+	double ungapped_evalue_short;
+	size_t max_swipe_dp;
 
 	Sensitivity sensitivity;
 	TracebackMode traceback_mode;
@@ -274,6 +282,7 @@ struct Config
 	string	cluster_similarity;
 
 	size_t max_size_set;
+	bool external;
 	string_vector cluster_steps;
 	double cluster_mcl_inflation;
 	uint32_t cluster_mcl_expansion;
@@ -285,7 +294,8 @@ struct Config
 
 	
 	std::map<std::string, Sensitivity> sens_map{
-		{"fast", Sensitivity::FAST},
+		{"fast", Sensitivity::FAST },
+		{"default", Sensitivity::DEFAULT},
 		{"sensitive", Sensitivity::SENSITIVE},
 		{"mid-sensitive", Sensitivity::MID_SENSITIVE},
 		{"more-sensitive", Sensitivity::MORE_SENSITIVE},
@@ -322,6 +332,7 @@ struct Config
 	}
 
 	void set_sens(Sensitivity sens);
+	std::string single_query_file() const;
 
 	bool mem_buffered() const { return tmpdir == "/dev/shm"; }
 
