@@ -25,8 +25,12 @@ struct Const
 {
 
 	enum {
-		build_version = 144,
+		build_version = 145,
+#ifdef SINGLE_THREADED
+		seedp_bits = 0,
+#else
 		seedp_bits = 10,
+#endif
 		seedp = 1<<seedp_bits,
 		max_seed_weight = 32,
 		max_shapes = 64
