@@ -19,9 +19,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef SHAPE_CONFIG_H_
 #define SHAPE_CONFIG_H_
 
+#include <vector>
+#include <algorithm>
+#include <stdint.h>
+#include <string>
 #include "shape.h"
 
-extern const char* shape_codes[12][Const::max_shapes];
+extern std::vector<std::vector<std::string>> shape_codes;
 
 class shape_config
 {
@@ -38,10 +42,9 @@ public:
 		mode_ (mode)
 	{
 		if (shape_mask.size() == 0) {
-			unsigned maxShapes = count == 0 ? Const::max_shapes : count;
+			unsigned maxShapes = count == 0 ? (unsigned)shape_codes[mode_].size() : count;
 			for (unsigned i = 0; i < maxShapes; ++i)
-				if (shape_codes[mode_][i])
-					shapes_[n_++] = Shape(shape_codes[mode_][i], i);
+				shapes_[n_++] = Shape(shape_codes[mode_][i].c_str(), i);
 		}
 		else {
 			for (unsigned i = 0; i < (count == 0 ? shape_mask.size() : std::min((unsigned)shape_mask.size(), count)); ++i)
@@ -65,6 +68,13 @@ public:
 		return s;
 	}
 
+	std::vector<uint32_t> patterns(unsigned begin, unsigned end) const {
+		std::vector<uint32_t> v;
+		for (unsigned i = begin; i < end; ++i)
+			v.push_back(shapes_[i].mask_);
+		return v;
+	}
+
 private:
 
 	Shape shapes_[Const::max_shapes];
