@@ -26,12 +26,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <set>
 #include "../basic/sequence.h"
 #include "../basic/match.h"
-#include "../basic/score_matrix.h"
+#include "../stats/score_matrix.h"
 //#include "../align/extend_ungapped.h"
 #include "../output/output_format.h"
 #include "../dp/hsp_traits.h"
 #include "chaining.h"
 
+using std::endl;
+using std::cout;
 using std::map;
 using std::list;
 using std::set;
