@@ -26,6 +26,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include <stdint.h>
 #include <limits.h>
+#include <list>
 #include "../util/io/serializer.h"
 #include "../util/io/input_file.h"
 #include "../util/io/text_input_file.h"
@@ -34,9 +35,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "metadata.h"
 #include "../util/data_structures/bit_vector.h"
 
-using std::vector;
-using std::string;
-
 struct ReferenceHeader
 {
 	ReferenceHeader() :
@@ -146,7 +144,7 @@ private:
 
 };
 
-void make_db(TempFile **tmp_out = nullptr, TextInputFile *input_file = nullptr);
+void make_db(TempFile **tmp_out = nullptr, std::list<TextInputFile>* input_file = nullptr);
 
 struct ref_seqs
 {
@@ -157,6 +155,19 @@ struct ref_seqs
 	static Sequence_set *data_;
 };
 
+struct ref_seqs_unmasked
+{
+	static const Sequence_set& get()
+	{
+		return *data_;
+	}
+	static Sequence_set& get_nc()
+	{
+		return *data_;
+	}
+	static Sequence_set* data_;
+};
+
 struct ref_ids
 {
 	static const String_set<char, 0>& get()
