@@ -31,6 +31,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "taxon_list.h"
 #include "taxonomy_nodes.h"
 #include "../util/util.h"
+#include "../util/data_structures/bit_vector.h"
 
 std::string get_accession(const string &t);
 
@@ -125,7 +126,7 @@ struct Taxonomy
 
 extern Taxonomy taxonomy;
 
-struct TaxonomyFilter : public std::vector<bool>
+struct TaxonomyFilter : public BitVector
 {
 	TaxonomyFilter(const std::string &include, const std::string &exclude, const TaxonList &list, TaxonomyNodes &nodes);
 };
