@@ -169,52 +169,6 @@ const Fixed_score_buffer<_score>& needleman_wunsch(sequence query, sequence subj
 
 template const Fixed_score_buffer<int>& needleman_wunsch<int, Local>(sequence query, sequence subject, int &max_score, const Local&, const int&);
 
-int needleman_wunsch(sequence query, sequence subject, int qbegin, int qend, int sbegin, int send, unsigned node, unsigned edge, Diag_graph &diags, bool log)
-{
-	const sequence q = query.subseq(qbegin, qend), s = subject.subseq(sbegin, send);
-	int max_score;
-	const Fixed_score_buffer<int> &dp = needleman_wunsch(q, s, max_score, Global(), int());
-	Diagonal_node *d = &diags[node];
-	unsigned start_node = diags.edges[edge].node_out;
-	vector<Diag_graph::Edge>::iterator f = diags.edges.begin() + edge;
-
-	/*if (log)
-		cout << dp << endl;*/
-
-	const int gap_open = score_matrix.gap_open(), gap_extend = score_matrix.gap_extend();
-	int l, i = qend - qbegin, j = send - sbegin;
-	const int score = dp(i, j);
-
-	l = have_diag(dp, i, j, q, s, log);
-	if (l > 0) {
-		i -= l;
-		j -= l;
-		f->j = sbegin + j;
-	}
-
-	while (i > 0 && j > 0) {
-		if ((l = have_diag(dp, i, j, q, s, log)) > 0) {
-			i -= l;
-			j -= l;
-			if (i != 0 || j != 0) {
-				f->node_out = (unsigned)diags.nodes.size();
-				diags.nodes.emplace_back(qbegin + i, sbegin + j, l, 0, (int)diags.edges.size());
-			}
-		}
-		else if (have_hgap(dp, i, j, gap_open, gap_extend, l)) {
-			j -= l;
-		}
-		else if (have_vgap(dp, i, j, gap_open, gap_extend, l)) {
-			i -= l;
-		}
-		else
-			throw std::runtime_error("Traceback error.");
-	}
-
-	f->node_out = start_node;
-	return score;
-}
-
 void smith_waterman(sequence q, sequence s, Hsp &out)
 {
 	int max_score;
@@ -262,67 +216,4 @@ void smith_waterman(sequence q, sequence s, Hsp &out)
 	out.query_source_range = out.query_range;
 	out.transcript.reverse();
 	out.transcript.push_terminator();
-}
-
-void print_diag(int i0, int j0, int l, int score, const Diag_graph &diags, const sequence &query, const sequence &subject)
-{
-	Diagonal_segment ds(i0, j0, l, 0);
-	unsigned n = 0;
-	int path_max,path_min;
-	for (vector<Diagonal_node>::const_iterator d = diags.nodes.begin(); d != diags.nodes.end(); ++d) {
-		if (d->intersect(ds).len > 0) {
-			if (d->score == 0)
-				continue;
-			const int diff = score_range(query, subject, d->query_end(), d->subject_end(), j0 + l);
-			if (n > 0)
-				cout << "(";
-			cout << "Diag n=" << d - diags.nodes.begin() << " i=" << i0 << " j=" << j0 << " len=" << l
-				<< " prefix_score=" << score + score_range(query, subject, i0 + l, j0 + l, d->subject_end()) - std::min(diff, 0)
-				<< " prefix_score2=" << diags.prefix_score((unsigned)(d - diags.nodes.begin()), j0 + l, path_max,path_min);
-			if (n > 0)
-				cout << ")";
-			cout << endl;
-			++n;
-		}
-	}
-	if(n == 0)
-		cout << "Diag n=x i=" << i0 << " j=" << j0 << " len=" << l << " prefix_score=" << score << endl;
-}
-
-void smith_waterman(sequence q, sequence s, const Diag_graph &diags)
-{
-	Hsp hsp;
-	smith_waterman(q, s, hsp);
-	Hsp::Iterator i = hsp.begin();
-	int i0 = -1, j0 = -1, l = 0, score = 0;
-	for (; i.good(); ++i) {
-		switch (i.op()) {
-		case op_match:
-		case op_substitution:
-			if (i0 < 0) {
-				i0 = i.query_pos.translated;
-				j0 = i.subject_pos;
-				l = 0;
-			}
-			score += score_matrix(q[i.query_pos.translated], s[i.subject_pos]);
-			++l;
-			break;
-		case op_deletion:
-		case op_insertion:
-			if (i0 >= 0) {
-				print_diag(i0, j0, l, score, diags, q, s);
-				score -= score_matrix.gap_open() + score_matrix.gap_extend();
-				i0 = -1;
-				j0 = -1;
-			}
-			else
-				score -= score_matrix.gap_extend();
-			break;
-		case op_frameshift_forward:
-		case op_frameshift_reverse:
-			;
-		}
-	}
-	print_diag(i0, j0, l, score, diags, q, s);
-	print_hsp(hsp, TranslatedSequence(q));
 }
\ No newline at end of file
