@@ -59,6 +59,16 @@ struct score_vector<int16_t>
 		data_(_mm256_loadu_si256((const __m256i*)x))
 	{}
 
+	score_vector(int16_t a, int16_t b, uint32_t mask) {
+		alignas(32) int16_t s[16];
+		for (uint32_t i = 0; i < 16; ++i)
+			if (mask & (1 << i))
+				s[i] = b;
+			else
+				s[i] = a;
+		data_ = _mm256_load_si256(reinterpret_cast<const __m256i*>(s));
+	}
+
 	score_vector(unsigned a, Register seq)
 	{
 		const __m256i* row_lo = reinterpret_cast<const __m256i*>(&score_matrix.matrix8u_low()[a << 5]);
@@ -150,12 +160,21 @@ struct score_vector<int16_t>
 	}
 
 	void expand_from_8bit() {
-		alignas(32) int8_t v[32];
-		alignas(32) int16_t w[16];
-		_mm256_storeu_si256((__m256i*)v, data_);
-		for (int i = 0; i < 16; ++i)
-			w[i] = v[i];
-		data_ = _mm256_load_si256((__m256i*)w);
+		__m128i in = _mm256_extractf128_si256(data_, 0);
+		__m128i mask = _mm_set1_epi8((char)0x80);
+		__m128i sign = _mm_cmpeq_epi8(_mm_and_si128(in, mask), mask);
+		__m128i low = _mm_unpacklo_epi8(in, sign);
+		__m128i hi = _mm_unpackhi_epi8(in, sign);
+		data_ = _mm256_set_m128i(hi, low);
+	}
+
+	friend std::ostream& operator<<(std::ostream& s, score_vector v)
+	{
+		int16_t x[16];
+		v.store(x);
+		for (unsigned i = 0; i < 16; ++i)
+			printf("%3i ", (int)x[i]);
+		return s;
 	}
 
 	__m256i data_;
@@ -196,6 +215,16 @@ struct score_vector<int16_t>
 		data_(_mm_loadu_si128((const __m128i*)x))
 	{}
 
+	score_vector(int16_t a, int16_t b, uint32_t mask) {
+		alignas(32) int16_t s[8];
+		for (uint32_t i = 0; i < 8; ++i)
+			if (mask & (1 << i))
+				s[i] = b;
+			else
+				s[i] = a;
+		data_ = _mm_load_si128(reinterpret_cast<const __m128i*>(s));
+	}
+
 	score_vector(unsigned a, uint64_t seq)
 	{
 		const uint16_t* row((uint16_t*)&score_matrix.matrix16()[a << 5]);
@@ -313,6 +342,21 @@ struct score_vector<int16_t>
 		data_ = _mm_loadu_si128((__m128i*)d);
 	}
 
+	void expand_from_8bit() {
+		__m128i mask = _mm_set1_epi8((char)0x80);
+		__m128i sign = _mm_cmpeq_epi8(_mm_and_si128(data_, mask), mask);
+		data_ = _mm_unpacklo_epi8(data_, sign);
+	}
+
+	friend std::ostream& operator<<(std::ostream& s, score_vector v)
+	{
+		int16_t x[8];
+		v.store(x);
+		for (unsigned i = 0; i < 8; ++i)
+			printf("%3i ", (int)x[i]);
+		return s;
+	}
+
 	__m128i data_;
 
 };
@@ -400,4 +444,8 @@ static inline DISPATCH_ARCH::score_vector<int16_t> load_sv(const uint16_t *x) {
 	return DISPATCH_ARCH::score_vector<int16_t>(x);
 }
 
+static inline DISPATCH_ARCH::score_vector<int16_t> load_sv(int16_t a, int16_t b, uint32_t mask) {
+	return DISPATCH_ARCH::score_vector<int16_t>(a, b, mask);
+}
+
 #endif
\ No newline at end of file
