@@ -23,7 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdint.h>
 #include <algorithm>
 #include "../dp.h"
-#include "../basic/value.h"
+#include "../../basic/value.h"
 #include "../../util/simd/vector.h"
 #include "../../util/dynamic_iterator.h"
 #include "../../stats/hauser_correction.h"
@@ -281,7 +281,7 @@ struct AsyncTargetBuffer
 			return dp_targets[channel].seq[pos[channel]];
 		}
 		else
-			return SUPER_HARD_MASK;;
+			return SUPER_HARD_MASK;
 	}
 
 #ifdef __SSSE3__
