@@ -94,7 +94,9 @@ const vector<OutputField> Blast_tab_format::field_def = {
 { "cigar", "CIGAR", true, false },		// 58
 { "skingdoms", "Subject kingdoms", false, false },	// 59
 { "sphylums", "Subject phylums", false, false },		// 60
-{ "ungapped_score", "Ungapped score", false, false }	// 61
+{ "ungapped_score", "Ungapped score", false, false },	// 61
+{ "full_qseq_mate", "Query sequence of the mate", false, false }, // 62
+{ "qseq_translated", "Aligned part of query sequence (translated)", true, false } // 63 needs transcript only in frameshift mode
 };
 
 Blast_tab_format::Blast_tab_format() :
@@ -134,6 +136,10 @@ Blast_tab_format::Blast_tab_format() :
 			config.use_lazy_dict = true;
 		if (j == 49 || j == 53)
 			config.store_query_quality = true;
+		if (j == 62)
+			needs_paired_end_info = true;
+		if ((j == 62 || j == 63) && !align_mode.query_translated)
+			throw std::runtime_error("Output field only supported for translated search.");
 		if (field_def[j].need_transcript)
 			needs_transcript = true;
 		if (field_def[j].need_stats)
@@ -377,6 +383,31 @@ void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadat
 		case 61:
 			out << r.ungapped_score;
 			break;
+		case 62: {
+			if (config.query_file.size() == 2) {
+				unsigned mate = r.query_id % 2, mate_id = mate == 0 ? r.query_id + 1 : r.query_id - 1;
+				query_source_seqs::get()[mate_id].print(out, input_value_traits);
+				break;
+			}
+			else {
+				out << '*';
+				break;
+			}
+		}
+		case 63: {
+			if (config.frame_shift) {
+				vector<Letter> seq;
+				seq.reserve(r.query_range().length());
+				for (Hsp_context::Iterator j = r.begin(); j.good(); ++j)
+					if (j.op() != op_deletion && j.op() != op_frameshift_forward && j.op() != op_frameshift_reverse)
+						seq.push_back(j.query());
+				out << sequence(seq);
+			}
+			else {
+				r.query.index(r.frame()).print(out, r.query_range().begin_, r.query_range().end_, amino_acid_traits);
+			}
+			break;
+		}
 		default:
 			throw std::runtime_error(string("Invalid output field: ") + field_def[*i].key);
 		}
@@ -413,6 +444,7 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 			case 57:
 			case 59:
 			case 60:
+			case 63:
 				out << '*';
 				break;
 			case 12:
