@@ -22,11 +22,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/reference.h"
 #include "workflow.h"
 #include "../cluster/cluster_registry.h"
+#include "../output/recursive_parser.h"
 #include "../util/simd.h"
-#ifdef EXTRA
-#include "../extra/compare.h"
-#include "../extra/match_file.h"
-#endif
 
 using std::cout;
 using std::cerr;
@@ -119,6 +116,17 @@ int main(int ac, const char* av[])
 			pairwise();
 			break;
 		case Config::cluster:
+			// Why is cluster_similarity not set at the end of the Config constructor?
+			if(!config.cluster_similarity.empty()){
+				RecursiveParser rp(nullptr, config.cluster_similarity.c_str(), true);
+				try{
+					rp.evaluate();
+				}
+				catch (const runtime_error& e){
+					message_stream << "Could not evaluate the expression: " << config.cluster_similarity << endl;
+					throw e;
+				}
+			}
 			Workflow::Cluster::ClusterRegistry::get(config.cluster_algo)->run();
 			break;
 		case Config::translate:
@@ -166,35 +174,6 @@ int main(int ac, const char* av[])
 		case Config::rocid:
 			roc_id();
 			break;
-#ifdef EXTRA
-		case Config::compare:
-			compare();
-			break;
-		case Config::model_sim:
-			model_sim();
-			break;
-		case Config::test_extra:
-			test_main();
-			break;
-		case Config::benchmark:
-			benchmark_sw();
-			break;
-		case Config::seed_stat:
-			seed_stat();
-			break;
-		case Config::model_seqs:
-			model_seqs();
-			break;
-		case Config::opt:
-			opt();
-			break;
-		case Config::db_annot_stats:
-			db_annot_stats();
-			break;
-		case Config::match_file_stat:
-			match_file_stat();
-			break;
-#endif
 		default:
 			return 1;
 		}
