@@ -48,7 +48,8 @@ void seed_join_worker(
 	DoubleArray<SeedArray::_pos> *ref_seeds_hits)
 {
 	unsigned p;
-	const unsigned bits = (unsigned)ceil(shapes[0].weight_ * Reduction::reduction.bit_size_exact()) - Const::seedp_bits;
+	const unsigned bits = config.hashed_seeds ? sizeof(SeedArray::Entry::Key) * 8
+		: (unsigned)ceil(shapes[0].weight_ * Reduction::reduction.bit_size_exact()) - Const::seedp_bits;
 	while ((p = (*seedp)++) < seedp_range->end()) {
 		std::pair<DoubleArray<SeedArray::_pos>, DoubleArray<SeedArray::_pos>> join = hash_join(
 			Relation<SeedArray::Entry>(query_seeds->begin(p), query_seeds->size(p)),
@@ -71,7 +72,7 @@ void search_worker(atomic<unsigned> *seedp, const SeedPartitionRange *seedp_rang
 	statistics += stats;
 }
 
-void search_shape(unsigned sid, unsigned query_block, char *query_buffer, char *ref_buffer, const Parameters &params)
+void search_shape(unsigned sid, unsigned query_block, char *query_buffer, char *ref_buffer, const Parameters &params, const Hashed_seed_set* target_seeds)
 {
 	::partition<unsigned> p(Const::seedp, config.lowmem);
 	DoubleArray<SeedArray::_pos> query_seed_hits[Const::seedp], ref_seed_hits[Const::seedp];
@@ -97,7 +98,14 @@ void search_shape(unsigned sid, unsigned query_block, char *query_buffer, char *
 			ref_idx = new SeedArray(*ref_seqs::data_, sid, ref_hst.get(sid), range, ref_hst.partition(), ref_buffer, &no_filter);
 
 		timer.go("Building query seed array");
-		SeedArray *query_idx = new SeedArray(*query_seqs::data_, sid, query_hst.get(sid), range, query_hst.partition(), query_buffer, &no_filter);
+		SeedArray* query_idx;
+		if (target_seeds)
+			query_idx = new SeedArray(*query_seqs::data_, sid, range, target_seeds);
+		else
+			query_idx = new SeedArray(*query_seqs::data_, sid, query_hst.get(sid), range, query_hst.partition(), query_buffer, &no_filter);
+		timer.finish();
+
+		log_stream << "Indexed query seeds = " << query_idx->size() << '/' << query_seqs::get().letters() << ", reference seeds = " << ref_idx->size() << '/' << ref_seqs::get().letters() << endl;
 
 		timer.go("Computing hash join");
 		atomic<unsigned> seedp(range.begin());
@@ -115,6 +123,7 @@ void search_shape(unsigned sid, unsigned query_block, char *query_buffer, char *
 		context = new Search::Context{ {patterns.data(), patterns.data() + patterns.size() - 1 },
 			{patterns.data(), patterns.data() + patterns.size() },
 			config.ungapped_evalue,
+			config.ungapped_evalue_short,
 			score_matrix.rawscore(config.short_query_ungapped_bitscore)
 		};
 
