@@ -36,7 +36,7 @@ void mcl() {
 }
 
 void split() {
-	TextInputFile in(config.query_file);
+	TextInputFile in(config.single_query_file());
 	string id;
 	vector<Letter> seq;
 	size_t n = 0, f = 0, b = (size_t)(config.chunk_size * 1e9);
