@@ -1,12 +1,13 @@
 #ifndef UTIL_ALGO_ALGO_H_
 #define UTIL_ALGO_ALGO_H_
 
+#include <stdint.h>
 #include <vector>
 
 namespace Util { namespace Algo {
 
 struct Edge {
-	int v1, v2, weight;
+	uint32_t v1, v2, weight;
 	bool operator<(const Edge &x) const {
 		return weight > x.weight;
 	}
