@@ -19,7 +19,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef INTERVAL_H_
 #define INTERVAL_H_
 
-#include <iostream>
+#include <ostream>
 #include <algorithm>
 
 struct interval
