@@ -41,9 +41,9 @@ unsigned TempFile::n = 0;
 uint64_t TempFile::hash_key;
 
 #ifdef _MSC_VER
-string TempFile::init()
+string TempFile::init(bool unlink)
 #else
-pair<string, int> TempFile::init()
+pair<string, int> TempFile::init(bool unlink)
 #endif
 {
 	vector<char> buf(config.tmpdir.length() + 64);
@@ -70,23 +70,28 @@ pair<string, int> TempFile::init()
 		perror(0);
 		throw std::runtime_error(string("Error opening temporary file ") + string(s));
 	}
-	if (config.no_unlink)
+	if (config.no_unlink || !unlink)
 		unlinked = false;
 	else
-		unlinked = (unlink(s) >= 0);
+		unlinked = (::unlink(s) >= 0);
 	return std::make_pair(string(s), fd);
 #endif
 }
 
-TempFile::TempFile():
+TempFile::TempFile(bool unlink):
 #ifdef _MSC_VER
-	OutputFile(init(), false, "w+b")
+	OutputFile(init(unlink), false, "w+b")
 #else
-	OutputFile(init(), "w+b")
+	OutputFile(init(unlink), "w+b")
 #endif
 {
 }
 
+TempFile::TempFile(const std::string & file_name):
+	OutputFile(file_name)
+{
+}
+
 string TempFile::get_temp_dir()
 {
 	TempFile t;
