@@ -1,6 +1,10 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2020 Max Planck Society for the Advancement of Science e.V.
+                        Benjamin Buchfink
+                        Eberhard Karls Universitaet Tuebingen
+						
+Code developed by Benjamin Buchfink <benjamin.buchfink@tue.mpg.de>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -16,16 +20,12 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
-#ifndef SEQ_FILE_FORMAT_H_
-#define SEQ_FILE_FORMAT_H_
-
+#pragma once
 #include <vector>
+#include <string>
 #include "../basic/value.h"
 #include "io/text_input_file.h"
 
-using std::vector;
-using std::pair;
-
 struct file_format_exception : public std::exception
 {
 	virtual const char* what() const throw()
@@ -37,7 +37,7 @@ struct file_format_exception : public std::exception
 struct Sequence_file_format
 {
 
-	virtual bool get_seq(vector<char> &id, vector<Letter> &seq, TextInputFile &s, vector<char> *qual = nullptr) const = 0;
+	virtual bool get_seq(std::string &id, std::vector<Letter> &seq, TextInputFile &s, const Value_traits& value_traits, std::vector<char> *qual = nullptr) const = 0;
 	virtual ~Sequence_file_format()
 	{ }
 	
@@ -49,7 +49,7 @@ struct FASTA_format : public Sequence_file_format
 	FASTA_format()
 	{ }
 
-	virtual bool get_seq(vector<char> &id, vector<Letter> &seq, TextInputFile &s, vector<char> *qual = nullptr) const;
+	virtual bool get_seq(std::string &id, std::vector<Letter> &seq, TextInputFile &s, const Value_traits& value_traits, std::vector<char> *qual = nullptr) const override;
 
 	virtual ~FASTA_format()
 	{ }
@@ -62,13 +62,11 @@ struct FASTQ_format : public Sequence_file_format
 	FASTQ_format()
 	{ }
 
-	virtual bool get_seq(vector<char> &id, vector<Letter> &seq, TextInputFile &s, vector<char> *qual = nullptr) const;
+	virtual bool get_seq(std::string &id, std::vector<Letter> &seq, TextInputFile &s, const Value_traits& value_traits, std::vector<char> *qual = nullptr) const override;
 
 	virtual ~FASTQ_format()
 	{ }
 
 };
 
-const Sequence_file_format* guess_format(TextInputFile &file);
-
-#endif /* SEQ_FILE_FORMAT_H_ */
\ No newline at end of file
+const Sequence_file_format* guess_format(TextInputFile &file);
\ No newline at end of file
