@@ -20,6 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define UTIL_SEQUENCE_SEQUENCE_H_
 
 #include <string>
+#include <string.h>
 #include "../../basic/sequence.h"
 #include "../io/output_file.h"
 
@@ -27,6 +28,18 @@ namespace Util { namespace Sequence {
 
 void format(sequence seq, const char *id, const char *qual, OutputFile &out, const std::string &format, const Value_traits &value_traits);
 
+static inline sequence clip(const Letter *seq, int len, int anchor) {
+	const Letter *a = seq + anchor, *begin = seq, *end = seq + len, *p;
+	for(;;) {
+		p = (const Letter*)memchr(begin, (int)sequence::DELIMITER, end - begin);
+		if (p == nullptr)
+			return sequence(begin, end);
+		if (p >= a)
+			return sequence(begin, p);
+		begin = p + 1;
+	}
+}
+
 }}
 
 #endif
\ No newline at end of file
