@@ -43,12 +43,4 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #else
 #define POSIX_OPEN(x,y,z) open(x,y,z)
 #define POSIX_OPEN2(x,y) open(x,y)
-#endif
-
-#if defined(__s390x__) && defined(__clang__)
-#define TLS_FIX_S390X
-#define TLS_FIX_S390X_MOVE(x) x
-#else
-#define TLS_FIX_S390X thread_local
-#define TLS_FIX_S390X_MOVE(x) std::move(x)
 #endif
\ No newline at end of file
