@@ -22,12 +22,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define TANTAN_H_
 
 #include "simd.h"
+#include "../basic/value.h"
 
 namespace Util { namespace tantan {
 
-typedef float float_t;
-
-DECL_DISPATCH(void, mask, (char *seq, int len, const float_t **likelihood_ratio_matrix, float_t p_repeat, float_t p_repeat_end, float_t repeat_decay, float_t p_mask, const char *maskTable))
+DECL_DISPATCH(void, mask, (Letter *seq, int len, const float **likelihood_ratio_matrix, float p_repeat, float p_repeat_end, float repeat_decay, float p_mask, const Letter *maskTable))
 
 }}
 
